@@ -1,8 +1,9 @@
+from django.conf.urls.defaults import patterns, url
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from django.conf.urls.defaults import patterns, url
 from feincms.content.application import models as app_models
 
+
 def register(cls, admin_cls):
     cls.add_to_class('category', models.ForeignKey('articles.Category', verbose_name=_('category')))
 
@@ -28,13 +29,6 @@ def register(cls, admin_cls):
     if admin_cls:
         admin_cls.list_filter += [ 'category',]
         admin_cls.list_display.insert(1, 'category', )
-
-
-        if admin_cls.fieldsets:
-            fields = admin_cls.fieldsets[0][1]['fields']
-            try:
-                at = fields.index('title')
-            except ValueError:
-                at = len(fields)
-            fields.insert(at, 'category')
-
+        admin_cls.add_extension_options(_('Category'), {
+            'fields': ('category',),
+        })
